package com.ynet.life.loaf.jdbc;

import java.io.IOException;
import java.io.Reader;
import java.math.BigDecimal;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import org.springframework.jdbc.support.lob.OracleLobHandler;
import org.springframework.jdbc.support.nativejdbc.CommonsDbcpNativeJdbcExtractor;

/* loaded from: com_ynet_life_loaf_jdbc.jar:com/ynet/life/loaf/jdbc/LoafPreparedData.class */
public class LoafPreparedData {
    private Integer dataType;
    private Object dataValue;
    private static OracleLobHandler lobHandler;

    static {
        CommonsDbcpNativeJdbcExtractor jdbcExtractor = new CommonsDbcpNativeJdbcExtractor();
        OracleLobHandler oracleLobHandler = new OracleLobHandler();
        lobHandler = oracleLobHandler;
        oracleLobHandler.setNativeJdbcExtractor(jdbcExtractor);
    }

    public LoafPreparedData(Integer dataType) {
        this.dataType = dataType;
    }

    public LoafPreparedData(Integer dataType, Object dataValue) {
        this.dataType = dataType;
        this.dataValue = dataValue;
    }

    public void fillStatement(PreparedStatement statement, int position) throws SQLException {
        switch (this.dataType.intValue()) {
            case 3:
                statement.setBigDecimal(position, new BigDecimal(getDataValue().toString()));
                return;
            case 4:
                statement.setInt(position, Integer.parseInt(getDataValue().toString()));
                return;
            case 12:
                statement.setString(position, getDataValue().toString());
                return;
            case 2004:
                lobHandler.getLobCreator().setBlobAsBytes(statement, position, (byte[]) getDataValue());
                return;
            case 2005:
                lobHandler.getLobCreator().setClobAsString(statement, position, getDataValue().toString());
                return;
            default:
                return;
        }
    }

    public void fetchResult(ResultSet resultSet, String fieldName) throws SQLException {
        switch (this.dataType.intValue()) {
            case 3:
                BigDecimal data = resultSet.getBigDecimal(fieldName);
                this.dataValue = data == null ? null : data.toString();
                return;
            case 2004:
                break;
            case 2005:
                this.dataValue = lobHandler.getClobAsString(resultSet, fieldName);
                break;
            default:
                this.dataValue = resultSet.getString(fieldName);
                return;
        }
        this.dataValue = lobHandler.getBlobAsBytes(resultSet, fieldName);
    }

    private String getTextData(Reader in) throws IOException {
        StringBuffer resultBuffer = new StringBuffer();
        char[] cbuf = new char[1024];
        while (true) {
            int readSize = in.read(cbuf, 0, 1024);
            if (readSize != -1) {
                if (readSize == 1024) {
                    resultBuffer.append(cbuf);
                } else {
                    resultBuffer.append(String.valueOf(cbuf, 0, readSize));
                }
            } else {
                return resultBuffer.toString();
            }
        }
    }

    public String toString() {
        switch (this.dataType.intValue()) {
            case 3:
            case 4:
                return getDataValue().toString();
            case 12:
            case 2005:
                return "'" + getDataValue().toString() + '\'';
            default:
                return getDataValue().toString();
        }
    }

    public Object getDataValue() {
        return this.dataValue;
    }
}
